pub struct Aes128 { /* private fields */ }Implementations
Sourceimpl Aes128
impl Aes128
Sourcepub fn encrypt_to_slice(&self, plain: &[u8], cipher: &mut [u8])
pub fn encrypt_to_slice(&self, plain: &[u8], cipher: &mut [u8])
Encrypts the input. The input must not be empty and its size must be a multiple of 16. The output size must be the same as the input size.
Sourcepub fn encrypt(&self, plain: &[u8]) -> Vec<u8>
pub fn encrypt(&self, plain: &[u8]) -> Vec<u8>
Encrypts the input. The input must not be empty and its size must be a multiple of 16.
Sourcepub fn decrypt_to_slice(&self, cipher: &[u8], plain: &mut [u8])
pub fn decrypt_to_slice(&self, cipher: &[u8], plain: &mut [u8])
Decrypts the input. The input must not be empty and its size must be a multiple of 16. The output size must be the same as the input size.